==> phyaat-0.0.2.tar.gz: phyaat-0.0.2/README.md <==
# PhyAAt: Physiology of Auditory Attention
## Predictive analysis of auditory attention from physiological signals

### **[Project Homepage](https://phyaat.github.io)**
### **[PyPi - project](https://pypi.org/project/phyaat/)**

### Links: **[Homepage](https://phyaat.github.io)** | **[Documentation](https://phyaat.readthedocs.io/)** | **[Github](https://github.com/Nikeshbajaj/phyaat)**  |  **[PyPi - project](https://pypi.org/project/phyaat/)** |     _ **Installation:** [pip install phyaat](https://pypi.org/project/phyaat/)
-----

[![Documentation Status](https://readthedocs.org/projects/phyaat/badge/?version=latest)](https://phyaat.readthedocs.io/en/latest/?badge=latest)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![PyPI version fury.io](https://badge.fury.io/py/phyaat.svg)](https://pypi.org/project/phyaat/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/phyaat.svg)](https://pypi.python.org/pypi/phyaat/)
[![GitHub release](https://img.shields.io/github/release/nikeshbajaj/phyaat.svg)](https://GitHub.com/nikeshbajaj/phyaat/releases/)
[![PyPI format](https://img.shields.io/pypi/format/phyaat.svg)](https://pypi.python.org/pypi/phyaat/)
[![PyPI implementation](https://img.shields.io/pypi/implementation/phyaat.svg)](https://pypi.python.org/pypi/phyaat/)
[![HitCount](http://hits.dwyl.io/nikeshbajaj/phyaat.svg)](http://hits.dwyl.io/nikeshbajaj/phyaat)
![GitHub commit activity](https://img.shields.io/github/commit-activity/y/nikeshbajaj/phyaat?style=plastic)
[![Percentage of issues still open](http://isitmaintained.com/badge/open/nikeshbajaj/phyaat.svg)](http://isitmaintained.com/project/nikeshbajaj/phyaat "Percentage of issues still open")
[![PyPI download month](https://img.shields.io/pypi/dm/phyaat.svg)](https://pypi.org/project/phyaat/)
[![PyPI download week](https://img.shields.io/pypi/dw/phyaat.svg)](https://pypi.org/project/phyaat/)


[![Generic badge](https://img.shields.io/badge/pip%20install-phyaat-blue.svg)](https://pypi.org/project/phyaat/)
[![Ask Me Anything !](https://img.shields.io/badge/Ask%20me-anything-1abc9c.svg)](mailto:n.bajaj@qmul.ac.uk)

![PyPI - Downloads](https://img.shields.io/pypi/dm/phyaat?style=social)


-----
## Table of contents
- [**Installation**](#installation)
- [**Getting Started**](#getting-started)
- [**Examples with Notebooks**](#examples)
-----


<p align="center">
  <img src="https://phyaat.github.io/assets/images/ExperimentModel.png" width="700"/>
</p>

<p align="center">
<img src="https://github.com/PhyAAt/PhyAAt.github.io/blob/master/assets/images/EEGViz_Raw1.gif" width="500"/>
</p>

### Requirement :
['numpy','scipy','matplotlib','spkit']

## Installation

### with pip

```
pip install phyaat
```

### Build from the source
Download the repository or clone it with git, after cd in directory build it from source with

```
python setup.py install
```

## Getting Started

For starting check here - **[Getting Started](https://phyaat.github.io/introduction.html)**



#### Contents are being updated on the webpage continuously, please check there for updates

______________________________________

# Contacts:

* **Nikesh Bajaj**
* http://nikeshbajaj.in
* n.bajaj@qmul.ac.uk
* bajaj.nikkey@gmail.com
### PhD Student: Queen Mary University of London & University of Genoa
______________________________________

==> phyaat-0.0.3.tar.gz: phyaat-0.0.3/README.md <==
# PhyAAt: Physiology of Auditory Attention
## Predictive analysis of auditory attention from physiological signals

### **[Project Homepage](https://phyaat.github.io)**
### **[PyPi - project](https://pypi.org/project/phyaat/)**

### Links: **[Homepage](https://phyaat.github.io)** | **[Documentation](https://phyaat.readthedocs.io/)** | **[Github](https://github.com/Nikeshbajaj/phyaat)**  |  **[PyPi - project](https://pypi.org/project/phyaat/)** |     _ **Installation:** [pip install phyaat](https://pypi.org/project/phyaat/)
-----

[![Documentation Status](https://readthedocs.org/projects/phyaat/badge/?version=latest)](https://phyaat.readthedocs.io/en/latest/?badge=latest)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![PyPI version fury.io](https://badge.fury.io/py/phyaat.svg)](https://pypi.org/project/phyaat/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/phyaat.svg)](https://pypi.python.org/pypi/phyaat/)
[![GitHub release](https://img.shields.io/github/release/nikeshbajaj/phyaat.svg)](https://GitHub.com/nikeshbajaj/phyaat/releases/)
[![PyPI format](https://img.shields.io/pypi/format/phyaat.svg)](https://pypi.python.org/pypi/phyaat/)
[![PyPI implementation](https://img.shields.io/pypi/implementation/phyaat.svg)](https://pypi.python.org/pypi/phyaat/)
[![HitCount](http://hits.dwyl.io/nikeshbajaj/phyaat.svg)](http://hits.dwyl.io/nikeshbajaj/phyaat)
![GitHub commit activity](https://img.shields.io/github/commit-activity/y/nikeshbajaj/phyaat?style=plastic)
[![Percentage of issues still open](http://isitmaintained.com/badge/open/nikeshbajaj/phyaat.svg)](http://isitmaintained.com/project/nikeshbajaj/phyaat "Percentage of issues still open")
[![PyPI download month](https://img.shields.io/pypi/dm/phyaat.svg)](https://pypi.org/project/phyaat/)
[![PyPI download week](https://img.shields.io/pypi/dw/phyaat.svg)](https://pypi.org/project/phyaat/)


[![Generic badge](https://img.shields.io/badge/pip%20install-phyaat-blue.svg)](https://pypi.org/project/phyaat/)
[![Ask Me Anything !](https://img.shields.io/badge/Ask%20me-anything-1abc9c.svg)](mailto:n.bajaj@qmul.ac.uk)

![PyPI - Downloads](https://img.shields.io/pypi/dm/phyaat?style=social)
<img src="https://static.pepy.tech/personalized-badge/phyaat?period=total&amp;units=international_system&amp;left_color=black&amp;right_color=orange&amp;left_text=Downloads" alt="PyPI - Downloads" />
<img alt="PyPI" src="https://img.shields.io/pypi/v/phyaat?color=g">

-----
## Table of contents
- [**Installation**](https://github.com/Nikeshbajaj/phyaat#installation)
- [**Getting Started**](https://phyaat.github.io/introduction.html)
- [**Examples with Notebooks**](https://phyaat.github.io/modeling/)
- [**Publications**](https://phyaat.github.io/authors#publicaions)
-----


<p align="center">
  <img src="https://phyaat.github.io/assets/images/ExperimentModel.png" width="700"/>
</p>

<p align="center">
<img src="https://github.com/PhyAAt/PhyAAt.github.io/blob/master/assets/images/EEGViz_Raw1.gif" width="500"/>
</p>

### Requirement :
['numpy','scipy','matplotlib','spkit']

## Installation

### with pip

```
pip install phyaat
```

### Build from the source
Download the repository or clone it with git, after cd in directory build it from source with

```
python setup.py install
```

## Getting Started

For starting check here - **[Getting Started](https://phyaat.github.io/introduction.html)**



#### Contents are being updated on the webpage continuously, please check there for updates

______________________________________

# Contacts:

* **Nikesh Bajaj**
* http://nikeshbajaj.in
* n.bajaj@qmul.ac.uk
* bajaj.nikkey@gmail.com
### PhD Student: Queen Mary University of London & University of Genoa
______________________________________
